@@ -1,26 +1,18 @@
-
-#    Copyright (c) 2008-2010 Dominique Dumont.
-#
-#    This file is part of Config-Model-TkUI.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
+# 
+# This file is part of Config-Model-TkUI
+# 
+# This software is Copyright (c) 2010 by Dominique Dumont.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+# 
 package Config::Model::Tk::HashEditor ;
+BEGIN {
+  $Config::Model::Tk::HashEditor::VERSION = '1.307';
+}
 
 use strict;
-our $VERSION="1.305";
 use warnings ;
 use Carp ;
 use Log::Log4perl ;
@@ -31,7 +23,7 @@ use subs qw/menu_struct/ ;
 use Tk::Dialog ;
 use Tk::Photo ;
 use Tk::Balloon ;
-
+use Config::Model::Tk::NoteEditor ;
 
 Construct Tk::Widget 'ConfigModelHashEditor';
 
@@ -88,7 +80,7 @@ sub Populate {
     $tklist->insert( end => $hash->get_all_indexes) ;
 
     my $right_frame = $elt_button_frame->Frame
-      ->pack(@fxe1, qw/-side right -anchor n/);
+      ->pack(@fbe1, qw/-side right -anchor n/);
 
     $cw->add_info() ;
     $cw->add_summary_and_description($hash) ;
@@ -173,6 +165,8 @@ sub Populate {
 					    },
 			    ) -> pack(-side => 'left', @fxe1) ;
 
+    $right_frame->ConfigModelNoteEditor( -object => $hash )->pack;
+
     $cw->{tklist} = $tklist ;
 
     $cw->Tk::Frame::Populate($args) ;
