@@ -1,37 +1,29 @@
-
-#    Copyright (c) 2008 Dominique Dumont.
-#
-#    This file is part of Config-Model-TkUI.
-#
-#    Config-Model is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser Public License as
-#    published by the Free Software Foundation; either version 2.1 of
-#    the License, or (at your option) any later version.
-#
-#    Config-Model is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-
+# 
+# This file is part of Config-Model-TkUI
+# 
+# This software is Copyright (c) 2010 by Dominique Dumont.
+# 
+# This is free software, licensed under:
+# 
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+# 
 package Config::Model::Tk::HashViewer ;
+BEGIN {
+  $Config::Model::Tk::HashViewer::VERSION = '1.307';
+}
 
 use strict;
-our $VERSION="1.305";
 use warnings ;
 use Carp ;
 
 use base qw/Tk::Frame Config::Model::Tk::AnyViewer/;
 use subs qw/menu_struct/ ;
 
-
 Construct Tk::Widget 'ConfigModelHashViewer';
 
 my @fbe1 = qw/-fill both -expand 1/ ;
 my @fxe1 = qw/-fill x    -expand 1/ ;
+my @fx   = qw/-fill    x / ;
 
 sub ClassInit {
     my ($cw, $args) = @_;
@@ -48,11 +40,12 @@ sub Populate {
     my $path = delete $args->{-path} 
       || die "HashViewer: no -path, got ",keys %$args;
 
-    $cw->add_header(View => $hash) ;
+    $cw->add_header(View => $hash)->pack(@fx) ;
 
     my $inst = $hash->instance ;
 
-    my $elt_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)->pack(@fxe1) ;
+    my $elt_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)
+      -> pack(@fbe1) ;
     my $str =  $hash->element_name.' '.$hash->get_type .' elements' ;
     $elt_frame -> Label(-text => $str) -> pack() ;
 
@@ -65,17 +58,19 @@ sub Populate {
 	$rt->insert('end', $c."\n" ) ;
     }
 
-    $cw->add_info($cw) ;
-    $cw->add_summary_and_description($hash) ;
-    $cw->add_editor_button($path) ;
+    $cw->add_annotation($hash) -> pack(@fx);
+    $cw->add_summary($hash)    -> pack(@fx) ;
+    $cw->add_description($hash)-> pack(@fx) ;
+
+    $cw->add_info_button()-> pack(-side => 'left',@fxe1) ;
+    $cw->add_editor_button($path)-> pack(-side => 'right', @fxe1) ;
 
     $cw->SUPER::Populate($args) ;
 }
 
 
-sub add_info {
+sub get_info {
     my $cw = shift ;
-    my $info_frame = shift ;
 
     my $hash = $cw->{hash} ;
 
@@ -96,7 +91,7 @@ sub add_info {
 	push @items, "$str: $v" if defined $v;
     }
 
-    $cw->add_info_frame(@items) ;
+    return ($hash->element_name, @items) ;
 }
 
 
